@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for shield service client paginators.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_shield import ShieldClient
-    from mypy_boto3_shield import (
+    from mypy_boto3_shield.paginator import (
         ListAttacksPaginator,
         ListProtectionsPaginator,
     )
@@ -18,9 +19,10 @@ Usage::
     list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_shield.type_defs import (
     ListAttacksResponseTypeDef,
     ListProtectionsResponseTypeDef,
@@ -28,13 +30,12 @@ from mypy_boto3_shield.type_defs import (
     TimeRangeTypeDef,
 )
 
-
 __all__ = ("ListAttacksPaginator", "ListProtectionsPaginator")
 
 
 class ListAttacksPaginator(Boto3Paginator):
     """
-    [Paginator.ListAttacks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/shield.html#Shield.Paginator.ListAttacks)
+    [Paginator.ListAttacks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/shield.html#Shield.Paginator.ListAttacks)
     """
 
     def paginate(
@@ -45,18 +46,18 @@ class ListAttacksPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAttacksResponseTypeDef]:
         """
-        [ListAttacks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
+        [ListAttacks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
         """
 
 
 class ListProtectionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListProtections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/shield.html#Shield.Paginator.ListProtections)
+    [Paginator.ListProtections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/shield.html#Shield.Paginator.ListProtections)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListProtectionsResponseTypeDef]:
         """
-        [ListProtections.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
+        [ListProtections.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
         """
